#
# spec file for package paprefs
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           paprefs
Version:        1.2
Release:        1.8
Summary:        PulseAudio Preferences
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://freedesktop.org/software/pulseaudio/paprefs
Source0:        %{url}/%{name}-%{version}.tar.xz

BuildRequires:  c++_compiler
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(giomm-2.4) >= 2.26
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(sigc++-2.0)
Requires:       pulseaudio-module-gsettings

%description
PulseAudio Preferences (paprefs) is a simple GTK based configuration
dialog for the PulseAudio sound server.

Please note that this program can only configure local servers, and
requires that a special module module-gconf is loaded in the sound
server.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file %{name} HardwareSettings AudioVideo Utility
%find_lang %{name} %{?no_lang_C}

%files
%license LICENSE
%{_bindir}/*
%{_datadir}/paprefs
%{_datadir}/applications/*.desktop

%files lang -f %{name}.lang

%changelog
* Sun Jan 23 2022 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 1.2:
  + Compatibility with PulseAudio 16.0 module paths
  + Crash bug fix
  + Updated translations.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Jul 23 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.1:
  + Replace dbus-glib and libdbus with gdbus.
  + Use module-combine-sink instead of module-combine.
- Drop paprefs-module-combine-sink.patch: Fixed upstream.
- Drop pkgconfig(dbus-glib-1) BuildRequires: No longer needed.
- Drop conditional post(un) handling of desktop_database_post(un)
  for obsolete versions of openSUSE, not needed for any currently
  supported version.
- Replace gcc-c++ with c++_compiler BuildRequires.
* Fri Oct  5 2018 bjorn.lie@gmail.com
- Update to version 1.0:
  + Port to meson.
- Stop using source service, new stable release out.
- Add meson BuildRequires and corresponding macros following
  upstreams port to meson.
- Drop intltool, libtool and lynx BuildRequires, no longer needed.
- Rebase paprefs-module-combine-sink.patch to upstream committed.
* Tue Jun 19 2018 bjorn.lie@gmail.com
- Add pulseaudio-module-gsettings Requires: paprefs now stores it's
  settings in GSettings.
* Mon Jun  4 2018 bjorn.lie@gmail.com
- Update to version 0.9.10+20180501.534d20a:
  + rename "module" to "module-group" in GSettings schemas and
    paths.
  + remove paprefs.convert.
  + Port from GTK2 to GTK3.
  + fix GSettings pkg-config dependency.
  + remove the GSettings schema file.
  + README: remove references to module-gconf.
  + build-sys: remove the gconf dependency.
  + Move from GConf to GSettings.
  + Added fixed port 5004 option for rtp sender.
  + doc: Drop 0pointer.de references.
  + modules: Better code for working out the dynamic module dir.
  + Do not require a recompile for each new PA version in order to
    detect the modules.
- Switch to gitcheckout via sources service, following this, add
  libtool and lynx BuildRequires, and pass boostrap.sh, now needed.
- Run spec-cleaner, modernize spec.
- Drop gconfmm-devel, libglademm-devel and xz BuildRequires, drop
  pulseaudio-module-gconf Requires: no longer after upstreams port
  and changes in obs.
- Add pkgconfig(dbus-glib-1), pkgconfig(giomm-2.4),
  pkgconfig(gtkmm-3.0), pkgconfig(libpulse) and
  pkgconfig(sigc++-2.0) BuildRequires, new dependencies.
- Replace libpulse-devel with pkgconfig(libpulse) BuildRequires.
- Rebase paprefs-module-combine-sink.patch.
* Fri Aug  8 2014 fcrozat@suse.com
- Improve category to .desktop file.
* Fri Sep 27 2013 oholecek@suse.cz
- Add paprefs-module-combine-sink.patch: use 'module-combine-sink'
  instead of obsoleted 'module-combine' (bnc#820594).
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 0.9.10:
  + Minor tidyups
  + Should no longer require recompiling with each new PA version
- Drop paprefs-packagekit.patch: fixed upstream.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Wed Sep 14 2011 vuntz@opensuse.org
- Add explicit dbus-1-glib-devel BuildRequires: it used to be
  brought in by something else before.
* Thu Jul 28 2011 vuntz@opensuse.org
- Add pulseaudio-module-gconf Requires, since paprefs sets gconf
  keys, which are only read if pulseaudio-module-gconf is
  installed. Might fix bnc#702549.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Split lang subpackage.
* Sun Sep  5 2010 vuntz@opensuse.org
- Do not add AudioVideo, SystemSetup, Mixer categories to
  paprefs.desktop, but just HardwareSettings so that the item
  appears with the sound preferences.
* Wed Feb 10 2010 sreeves@novell.com
- Add paprefs-packagekit.patch: only show install buttons if
  packagekit service is available
* Sat Sep 19 2009 sreeves@novell.com
- Update to version 0.9.9
  + wrap upnp mediaserver
  + implement basic packagekit support
* Thu Aug 20 2009 sreeves@novell.com
- Fix directory where we look for pulse modules
* Sat Aug 15 2009 beineri@opensuse.org
- put it into same start menu category than the other PA stuff
* Thu May  7 2009 vuntz@novell.com
- Review changes.
- Use parallel make.
- Use standard commands for clean section.
- Drop paprefs-0.9.6-libintl-fix.diff: not needed anymore,
  apparently.
- Drop paprefs-desktop-fix.diff and paprefs.png: there's no reason
  to change the icon like this. It was probably needed for a
  rpmlint warning, but it's fine now.
- Remove autoreconf call, which isn't needed anymore.
* Thu Apr 30 2009 opensuse@sukimashita.com
- Update to version 0.9.8:
  + Add RAOP (Apple Airport Express) enabling support
  + Updated translations
- Drop paprefs-speaker-setup.patch: this is obsoleted by pulseaudio
  0.9.15, see discussion at http://pulseaudio.org/ticket/164
* Mon Sep 15 2008 rodrigo@suse.de
- Update to version 0.9.7 (fate#303943):
  + Explicitly include libintl.h for FreeBSD compat
  + Modernize bootstrap.sh
  + Revert accidental license change
  + Minor updates
  + Updated translations
* Mon Jun  2 2008 rodrigo@suse.de
- Upstream patch that hadn't been upstreamed
* Wed May 14 2008 rodrigo@suse.de
- Added paprefs-speaker-setup.patch to add a GUI for setting
  different speaker setups (bnc#381686)
* Fri Jan 11 2008 rodrigo@suse.de
- Depend on libpulse-devel, not pulseaudio-devel
* Mon Nov  5 2007 tiwai@suse.de
- add missing inclusion of libintl.h
* Wed Oct 31 2007 tiwai@suse.de
- updated to version 0.9.6:
  * rework UI
  * add support to enable automatic zeroconf discovery
  * automatic device combination
  * i18n support
* Wed Jun 13 2007 tiwai@suse.de
- initial version: 0.9.5
